[![banner](https://raw.githubusercontent.com/nevermined-io/assets/main/images/logo/banner_logo.png)](https://nevermined.io)




# Nevermined Documentation

> http://docs.nevermined.io/


[![Twitter](https://img.shields.io/twitter/follow/nevermined_io?style=social)](https://twitter.com/nevermined_io)
[![Discord](https://img.shields.io/discord/775670012446507028.svg?color=7289da&label=Discord&logo=discord&style=flat-square)](https://discord.gg/GZju2qScKq)


Nevermined is a data ecosystem solution that provides the capabilities of
building bespoke networks where different entities can share and monetize their
data and make an efficient and secure usage of it even with untrusted parties.

With the explosion of the data and AI market, entities have the necessity of
organizing, understanding, using and sharing their data internally and
externally. Nevermined provides Data Sharing & Data in situ Computation solutions
allowing to unlock data for AI.

Nevermined enables a __“Data in situ Computation”__ solution, meaning the data never
moves, is the algorithm the one moving where the data is. It allows data owners
or providers to define the conditions in which they allow others to make use of
their data without giving direct access to it.

Nevermined is designed to be integrated in Big Data environments. It enables
monetizing the data without migration. It’s also designed for GDPR compliance,
it never stores any personal information on-chain (encrypted or in plain text).

Nevermined is the product powered by [Keyko](https://keyko.io).


## Social

Discord: https://discord.gg/GZju2qScKq
Twitter: https://twitter.com/Nevermined_io
Medium: https://medium.com/nevermined-io
LinkedIn: https://www.linkedin.com/company/nevermined
